[PATCH] -r 1-100 not -r1:100 please...

Rusty Russell rusty at rustcorp.com.au
Fri May 27 08:41:34 BST 2005


On Fri, 2005-05-27 at 14:22 +1000, Rusty Russell wrote:
> OK, you knew this was coming 8)

And another patch, this one add ranges to diff and included for free is
a "changeset" extension which is more useful than diff, eg:
	bzr changeset
	-- Print out last revision description then patch.
	bzr changeset -r5-8
	-- Print out changeset for revisions 5, 6, 7 and 8.

Cheers,
Rusty.

------------------------------------------------------------
revno: 573
committer: Rusty Russell <rusty at chopin>
timestamp: Fri 2005-05-27 16:16:37 +1000
message:
  Revision ranges for diff
*** modified file 'bzrlib/commands.py'
--- bzrlib/diff.py 
+++ bzrlib/diff.py 
@@ -144,15 +144,19 @@
     
 
 
-def show_diff(b, revision, specific_files, external_diff_options=None):
+def show_diff(b, start_revision, end_revision, specific_files,
+              external_diff_options=None):
     import sys
 
-    if revision == None:
+    if start_revision == None:
         old_tree = b.basis_tree()
     else:
-        old_tree = b.revision_tree(b.lookup_revision(revision))
+        old_tree = b.revision_tree(b.lookup_revision(start_revision))
         
-    new_tree = b.working_tree()
+    if end_revision == None:
+        new_tree = b.working_tree()
+    else:
+        new_tree = b.revision_tree(b.lookup_revision(end_revision))
 
     show_diff_trees(old_tree, new_tree, sys.stdout, specific_files,
                     external_diff_options)

--- bzrlib/commands.py 
+++ bzrlib/commands.py 
@@ -497,10 +497,13 @@
 
 
 class cmd_diff(Command):
     """Show differences in working tree.
     
     If files are listed, only the changes in those files are listed.
     Otherwise, all changes for the tree are listed.
+
+    If a single revision is given, show changes since that revision.
+    If a range is given, show changes between those revisions.
 
     TODO: Given two revision arguments, show the difference between them.
 
@@ -536,12 +539,16 @@
                 file_list = None
         else:
             b = Branch('.', lock_mode='r')
-    
-        show_diff(b, revision, specific_files=file_list,
+
+        if revision == None:
+            revision = [None, None]
+        elif isinstance(revision, int):
+            revision = [revision, None]
+            
+        show_diff(b, revision[0], revision[1], specific_files=file_list,
                   external_diff_options=diff_options)
 
 
-        
 
 
 class cmd_deleted(Command):
@@ -497,10 +497,13 @@
 
 class cmd_diff(Command):
-    """Show differences in working tree.
+    """Show differences in working tree, or between revisions.
     
     If files are listed, only the changes in those files are listed.

*** modified file 'bzrlib/diff.py'
-- 
A bad analogy is like a leaky screwdriver -- Richard Braakman
-------------- next part --------------
A non-text attachment was scrubbed...
Name: changeset
Type: application/x-shellscript
Size: 866 bytes
Desc: not available
Url : https://lists.ubuntu.com/archives/bazaar/attachments/20050527/26b8f617/attachment.bin 


More information about the bazaar mailing list